==> jc-1.4.0.tar.gz: java/applet/Applet__24AccessibleApplet.h <==
// public class java.applet.Applet$AccessibleApplet

// class file dependencies
// @dep_class cfc95431edfb3122 java_applet_Applet__24AccessibleApplet
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class cf70181aba087445 java_awt_Panel__24AccessibleAWTPanel
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Panel__24AccessibleAWTPanel

#include "java/awt/Panel__24AccessibleAWTPanel.h"

#ifndef _JC_java_applet_Applet__24AccessibleApplet_H_
#define _JC_java_applet_Applet__24AccessibleApplet_H_

// Forward structure declarations
struct _jc_java_applet_Applet$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_applet_Applet__24AccessibleApplet$sub_refs	_jc_java_applet_Applet__24AccessibleApplet$sub_refs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs	_jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$refs	_jc_java_applet_Applet__24AccessibleApplet$refs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$nonrefs	_jc_java_applet_Applet__24AccessibleApplet$nonrefs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$object	_jc_java_applet_Applet__24AccessibleApplet$object;

typedef struct _jc_java_applet_Applet__24AccessibleApplet$fields_struct	_jc_java_applet_Applet__24AccessibleApplet$fields_struct;
typedef const struct _jc_java_applet_Applet__24AccessibleApplet$vmethods	_jc_java_applet_Applet__24AccessibleApplet$vmethods;
typedef const struct _jc_java_applet_Applet__24AccessibleApplet$vtable	_jc_java_applet_Applet__24AccessibleApplet$vtable;
typedef const struct _jc_java_applet_Applet__24AccessibleApplet$vtype	_jc_java_applet_Applet__24AccessibleApplet$vtype;

// Class fields structure
struct _jc_java_applet_Applet__24AccessibleApplet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_applet_Applet__24AccessibleApplet$fields_struct _jc_java_applet_Applet__24AccessibleApplet$class_fields;

// Constructors
extern void _jc_java_applet_Applet__24AccessibleApplet$method$_init$a41b98a2d1f37a05(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *, struct _jc_java_applet_Applet$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_applet_Applet__24AccessibleApplet$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_applet_Applet__24AccessibleApplet$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *);

// Virtual method descriptors
extern _jc_method _jc_java_applet_Applet__24AccessibleApplet$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_applet_Applet__24AccessibleApplet$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_applet_Applet__24AccessibleApplet$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *);
};

// Vtable
struct _jc_java_applet_Applet__24AccessibleApplet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vmethods	java_awt_Panel__24AccessibleAWTPanel;
	_jc_java_applet_Applet__24AccessibleApplet$vmethods	java_applet_Applet__24AccessibleApplet;
};

// Vtype
struct _jc_java_applet_Applet__24AccessibleApplet$vtype {
	_jc_type			type;
	_jc_java_applet_Applet__24AccessibleApplet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_applet_Applet__24AccessibleApplet$sub_refs {
	struct _jc_java_applet_Applet$object	*this;
};

// Reference instance fields (object)
struct _jc_java_applet_Applet__24AccessibleApplet$refs {
    _jc_java_applet_Applet__24AccessibleApplet$sub_refs	java_applet_Applet__24AccessibleApplet;
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs	java_awt_Panel__24AccessibleAWTPanel;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_applet_Applet__24AccessibleApplet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs	java_awt_Panel__24AccessibleAWTPanel;
    _jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs	java_applet_Applet__24AccessibleApplet;
};

// Object instance structure
struct _jc_java_applet_Applet__24AccessibleApplet$object {
	_jc_java_applet_Applet__24AccessibleApplet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_applet_Applet__24AccessibleApplet$vtype	*vtype;
	_jc_java_applet_Applet__24AccessibleApplet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_applet_Applet__24AccessibleApplet$vtype _jc_java_applet_Applet__24AccessibleApplet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_applet_Applet__24AccessibleApplet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_applet_Applet__24AccessibleApplet$class_object;

#endif	/* _JC_java_applet_Applet__24AccessibleApplet_H_ */

==> jc-1.4.5.tar.gz: java/applet/Applet__24AccessibleApplet.h <==
// public class java.applet.Applet$AccessibleApplet

// class file dependencies
// @dep_class cfc95431edfb3122 java_applet_Applet__24AccessibleApplet
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class cf70181aba087445 java_awt_Panel__24AccessibleAWTPanel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Panel__24AccessibleAWTPanel

#include "java/awt/Panel__24AccessibleAWTPanel.h"

#ifndef _JC_java_applet_Applet__24AccessibleApplet_H_
#define _JC_java_applet_Applet__24AccessibleApplet_H_

// Forward structure declarations
struct _jc_java_applet_Applet$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_applet_Applet__24AccessibleApplet$sub_refs	_jc_java_applet_Applet__24AccessibleApplet$sub_refs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs	_jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$refs	_jc_java_applet_Applet__24AccessibleApplet$refs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$nonrefs	_jc_java_applet_Applet__24AccessibleApplet$nonrefs;
typedef struct _jc_java_applet_Applet__24AccessibleApplet$object	_jc_java_applet_Applet__24AccessibleApplet$object;

typedef struct _jc_java_applet_Applet__24AccessibleApplet$fields_struct	_jc_java_applet_Applet__24AccessibleApplet$fields_struct;
typedef const struct _jc_java_applet_Applet__24AccessibleApplet$vmethods	_jc_java_applet_Applet__24AccessibleApplet$vmethods;
typedef const struct _jc_java_applet_Applet__24AccessibleApplet$vtable	_jc_java_applet_Applet__24AccessibleApplet$vtable;
typedef const struct _jc_java_applet_Applet__24AccessibleApplet$vtype	_jc_java_applet_Applet__24AccessibleApplet$vtype;

// Class fields structure
struct _jc_java_applet_Applet__24AccessibleApplet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_applet_Applet__24AccessibleApplet$fields_struct _jc_java_applet_Applet__24AccessibleApplet$class_fields;

// Constructors
extern void _jc_java_applet_Applet__24AccessibleApplet$method$_init$a41b98a2d1f37a05(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *, struct _jc_java_applet_Applet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_applet_Applet__24AccessibleApplet$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_applet_Applet__24AccessibleApplet$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_applet_Applet__24AccessibleApplet$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_applet_Applet__24AccessibleApplet$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_applet_Applet__24AccessibleApplet$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_applet_Applet__24AccessibleApplet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_applet_Applet__24AccessibleApplet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_java_awt_Panel__24AccessibleAWTPanel$vmethods	java_awt_Panel__24AccessibleAWTPanel;
	_jc_java_applet_Applet__24AccessibleApplet$vmethods	java_applet_Applet__24AccessibleApplet;
};

// Vtype
struct _jc_java_applet_Applet__24AccessibleApplet$vtype {
	_jc_type			type;
	_jc_java_applet_Applet__24AccessibleApplet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_applet_Applet__24AccessibleApplet$sub_refs {
	struct _jc_java_applet_Applet$object	*this;
};

// Reference instance fields (object)
struct _jc_java_applet_Applet__24AccessibleApplet$refs {
    _jc_java_applet_Applet__24AccessibleApplet$sub_refs	java_applet_Applet__24AccessibleApplet;
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_refs	java_awt_Panel__24AccessibleAWTPanel;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_applet_Applet__24AccessibleApplet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Panel__24AccessibleAWTPanel$sub_nonrefs	java_awt_Panel__24AccessibleAWTPanel;
    _jc_java_applet_Applet__24AccessibleApplet$sub_nonrefs	java_applet_Applet__24AccessibleApplet;
};

// Object instance structure
struct _jc_java_applet_Applet__24AccessibleApplet$object {
	_jc_java_applet_Applet__24AccessibleApplet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_applet_Applet__24AccessibleApplet$vtype	*vtype;
	_jc_java_applet_Applet__24AccessibleApplet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_applet_Applet__24AccessibleApplet$vtype _jc_java_applet_Applet__24AccessibleApplet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_applet_Applet__24AccessibleApplet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_applet_Applet__24AccessibleApplet$class_object;

#endif	/* _JC_java_applet_Applet__24AccessibleApplet_H_ */
